# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TaskPriorityEnum(object):

    """Implementation of the 'TaskPriority' enum.

    The priority of a task.

    Attributes:
        LOW: TODO: type description here.
        MEDIUM: TODO: type description here.
        HIGH: TODO: type description here.

    """

    LOW = 'low'

    MEDIUM = 'medium'

    HIGH = 'high'

