# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class IntervalTypeEnum(object):

    """Implementation of the 'IntervalType' enum.

    The type of with which the task repeats.

    Attributes:
        DAY: TODO: type description here.
        WEEK: TODO: type description here.
        MONTH: TODO: type description here.
        YEAR: TODO: type description here.

    """

    DAY = 'day'

    WEEK = 'week'

    MONTH = 'month'

    YEAR = 'year'

