# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class PersonnelQualification(object):

    """Implementation of the 'PersonnelQualification' model.

    A personnel qualification.

    Attributes:
        qualification_id (int): The id of a personnel qualification.
        manufacturer (string): TODO: type description here.
        qualification_type (string): TODO: type description here.
        qualification_description (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "qualification_id":'qualificationId',
        "manufacturer":'manufacturer',
        "qualification_type":'qualificationType',
        "qualification_description":'qualificationDescription'
    }

    def __init__(self,
                 qualification_id=None,
                 manufacturer=None,
                 qualification_type=None,
                 qualification_description=None):
        """Constructor for the PersonnelQualification class"""

        # Initialize members of the class
        self.qualification_id = qualification_id
        self.manufacturer = manufacturer
        self.qualification_type = qualification_type
        self.qualification_description = qualification_description


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        qualification_id = dictionary.get('qualificationId')
        manufacturer = dictionary.get('manufacturer')
        qualification_type = dictionary.get('qualificationType')
        qualification_description = dictionary.get('qualificationDescription')

        # Return an object of this model
        return cls(qualification_id,
                   manufacturer,
                   qualification_type,
                   qualification_description)


