# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ClientConfiguration(object):

    """Implementation of the 'ClientConfiguration' model.

    General configuration data.

    Attributes:
        title (string): The title of your Greenbyte Platform website.
        tag (string): Your internal customer tag.
        url_web (string): Your URL to access the Greenbyte Platform website.
        url_api (string): Your URL to access the Greenbyte Platform API.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "title":'title',
        "tag":'tag',
        "url_web":'urlWeb',
        "url_api":'urlApi'
    }

    def __init__(self,
                 title=None,
                 tag=None,
                 url_web=None,
                 url_api=None):
        """Constructor for the ClientConfiguration class"""

        # Initialize members of the class
        self.title = title
        self.tag = tag
        self.url_web = url_web
        self.url_api = url_api


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        title = dictionary.get('title')
        tag = dictionary.get('tag')
        url_web = dictionary.get('urlWeb')
        url_api = dictionary.get('urlApi')

        # Return an object of this model
        return cls(title,
                   tag,
                   url_web,
                   url_api)


