# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ResolutionEnum(object):

    """Implementation of the 'Resolution' enum.

    The resolution for time-series data.

    Attributes:
        ENUM_5MINUTE: The data is presented in 5 minute resolution.
        ENUM_10MINUTE: The data is presented in 10 minute resolution.
        ENUM_15MINUTE: The data is presented in fifteen minute resolution.
        HOURLY: The data is presented in hourly resolution.
        DAILY: The data is presented in daily resolution.
        WEEKLY: The data is presented in weekly resolution.
        MONTHLY: The data is presented in monthly resolution.
        YEARLY: The data is presented in yearly resolution.
        INTERVAL: The data is presented as a single value for the interval.
        DEVICE: The device's own resolution is used.

    """

    ENUM_5MINUTE = '5minute'

    ENUM_10MINUTE = '10minute'

    ENUM_15MINUTE = '15minute'

    HOURLY = 'hourly'

    DAILY = 'daily'

    WEEKLY = 'weekly'

    MONTHLY = 'monthly'

    YEARLY = 'yearly'

    INTERVAL = 'interval'

    DEVICE = 'device'

