# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class User(object):

    """Implementation of the 'User' model.

    TODO: type model description here.

    Attributes:
        first_name (string): TODO: type description here.
        last_name (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "first_name":'firstName',
        "last_name":'lastName'
    }

    def __init__(self,
                 first_name=None,
                 last_name=None):
        """Constructor for the User class"""

        # Initialize members of the class
        self.first_name = first_name
        self.last_name = last_name


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        first_name = dictionary.get('firstName')
        last_name = dictionary.get('lastName')

        # Return an object of this model
        return cls(first_name,
                   last_name)


