# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TaskStateEnum(object):

    """Implementation of the 'TaskState' enum.

    The state of a task.

    Attributes:
        UNRESOLVED: TODO: type description here.
        RESOLVED: TODO: type description here.

    """

    UNRESOLVED = 'unresolved'

    RESOLVED = 'resolved'

