# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class StatusCategoryEnum(object):

    """Implementation of the 'StatusCategory' enum.

    The category a status belongs to.

    Attributes:
        STOP: Statuses indicating that the device is prevented from producing
            power or is in a critical state.
        WARNING: Statuses indicating that the device is not operating
            normally, but is not in a critical state.
        INFORMATIONAL: Statuses that occur during normal operation.
        COMMUNICATION: Statuses related to communication between the device
            and Greenbyte.
        CURTAILMENT: Statuses generated based on curtailment.

    """

    STOP = 'stop'

    WARNING = 'warning'

    INFORMATIONAL = 'informational'

    COMMUNICATION = 'communication'

    CURTAILMENT = 'curtailment'

