# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TaskAssigneeTypeEnum(object):

    """Implementation of the 'TaskAssigneeType' enum.

    The type of task assignee.

    Attributes:
        USER: A Greenbyte Platform user assignee.
        PERSONNEL: A personnel assignee.
        MANUFACTURER: The manufacturer as assignee.
        OTHER: Any other assignee.

    """

    USER = 'user'

    PERSONNEL = 'personnel'

    MANUFACTURER = 'manufacturer'

    OTHER = 'other'

