# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class CategoryEnum(object):

    """Implementation of the 'Category' enum.

    TODO: type enum description here.

    Attributes:
        PICTURES: TODO: type description here.
        REPORTS: TODO: type description here.
        OTHER: TODO: type description here.

    """

    PICTURES = 'Pictures'

    REPORTS = 'Reports'

    OTHER = 'Other'

