# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class CategoryTimeEnum(object):

    """Implementation of the 'CategoryTime' enum.

    TODO: type enum description here.

    Attributes:
        AVAILABLE: TODO: type description here.
        UNAVAILABLE: TODO: type description here.
        EXCLUDED: TODO: type description here.

    """

    AVAILABLE = 'available'

    UNAVAILABLE = 'unavailable'

    EXCLUDED = 'excluded'

