# -*- coding: utf-8 -*-

"""
    greenbyteapi

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class CalculationModeEnum(object):

    """Implementation of the 'CalculationMode' enum.

    Which operation to use when aggregating data.

    Attributes:
        AVERAGE: Returns the average of all data points in the range.
        SUM: Returns the sum of all data points in the range.
        COUNTER: Returns the raw accumulated counter data.

    """

    AVERAGE = 'average'

    SUM = 'sum'

    COUNTER = 'counter'

